Index: trunk/psLib/src/astro/psTime.h
===================================================================
--- trunk/psLib/src/astro/psTime.h	(revision 4330)
+++ trunk/psLib/src/astro/psTime.h	(revision 4409)
@@ -11,6 +11,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.32 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-21 03:01:37 $
+ *  @version $Revision: 1.33 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-28 20:17:52 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -38,8 +38,8 @@
  */
 typedef enum {
-    PS_TIME_TAI,        ///< Temps Atomique International (TAI) time (time with leapseconds).
-    PS_TIME_UTC,        ///< Universal Time Coordinated (UTC) time (time without leapseconds).
-    PS_TIME_UT1,        ///< Universal Time corrected for polar motion
-    PS_TIME_TT,         ///< Terrestrial Time
+    PS_TIME_TAI,                       ///< Temps Atomique International (TAI) time (time with leapseconds)
+    PS_TIME_UTC,                       ///< Universal Time Coordinated (UTC) time (time without leapseconds)
+    PS_TIME_UT1,                       ///< Universal Time corrected for polar motion
+    PS_TIME_TT,                        ///< Terrestrial Time
 } psTimeType;
 
@@ -49,6 +49,6 @@
  */
 typedef enum {
-    PS_IERS_A,          ///< IERS Bulletin A
-    PS_IERS_B,          ///< IERS Bulletin B
+    PS_IERS_A,                         ///< IERS Bulletin A
+    PS_IERS_B,                         ///< IERS Bulletin B
 } psTimeBulletin;
 
@@ -62,8 +62,8 @@
 typedef struct psTime
 {
-    psS64 sec;          ///< Seconds since epoch, Jan 1, 1970.
-    psU32 nsec;         ///< Nanoseconds since last second.
-    psBool leapsecond;  ///< if time falls on UTC leapsecond
-    psTimeType type;    ///< Type of time.
+    psS64 sec;                         ///< Seconds since epoch, Jan 1, 1970.
+    psU32 nsec;                        ///< Nanoseconds since last second.
+    psBool leapsecond;                 ///< if time falls on UTC leapsecond
+    psTimeType type;                   ///< Type of time.
 }
 psTime;
@@ -97,5 +97,5 @@
  */
 psTime* psTimeAlloc(
-    psTimeType type                     ///< Type of time to create (UTC or TAI).
+    psTimeType type                    ///< Type of time to create (UTC or TAI).
 );
 
@@ -108,5 +108,5 @@
  */
 psTime* psTimeGetNow(
-    psTimeType type                     ///< Type of time to get (UTC or TAI).
+    psTimeType type                    ///< Type of time to get (UTC or TAI).
 );
 
@@ -118,6 +118,6 @@
  */
 psTime* psTimeConvert(
-    psTime *time,                       ///< Time to be converted.
-    psTimeType type                     ///< Type to be converted to.
+    psTime *time,                      ///< Time to be converted.
+    psTimeType type                    ///< Type to be converted to.
 );
 
@@ -131,5 +131,5 @@
 double psTimeToLMST(
     psTime *time,                      ///< psTime to be converted.
-    double longitude                    ///< Longitude.
+    double longitude                   ///< Longitude.
 );
 
@@ -141,6 +141,6 @@
  */
 double psTimeGetUT1Delta(
-    const psTime *time,                 ///< psTime to be looked up.
-    psTimeBulletin bulletin             ///< IERS bulletin to use
+    const psTime *time,                ///< psTime to be looked up.
+    psTimeBulletin bulletin            ///< IERS bulletin to use
 );
 
@@ -152,5 +152,5 @@
  */
 psF64 p_psTimeGetTAIDelta(
-    const psTime *time                  ///< psTime to be looked up.
+    const psTime *time                 ///< psTime to be looked up.
 );
 
@@ -212,7 +212,7 @@
  *  This function does not add or subtract leapseconds.
  *
- *  @return  char*: Pointer null terminated array of chars in ISO time.
- */
-char* psTimeToISO(
+ *  @return  psString:     Pointer null terminated array of chars in ISO time.
+ */
+psString psTimeToISO(
     const psTime* time                  ///< Input time to be converted.
 );
@@ -268,5 +268,5 @@
  */
 psTime* psTimeFromISO(
-    const char* time                   ///< Input time to be converted.
+    const char* input                  ///< Input time to be converted.
 );
 
@@ -278,5 +278,5 @@
  */
 psTime* psTimeFromTimeval(
-    const struct timeval *time         ///< Input time to be converted.
+    const struct timeval *input        ///< Input time to be converted.
 );
 
@@ -296,5 +296,5 @@
  *  Converts UTC time to psTime.  It will verify if time specified is a leapsecond.
  *
- *  @return psTime*: time (UTC)
+ *  @return psTime*: time (UTC)time
  */
 psTime* psTimeFromUTC(
